# Changelog

## [5.0.1a1](https://github.com/OpenVoiceOS/ovos-workshop/tree/5.0.1a1) (2025-06-07)

[Full Changelog](https://github.com/OpenVoiceOS/ovos-workshop/compare/5.0.0...5.0.1a1)

**Merged pull requests:**

- fix: can\_answer converse [\#342](https://github.com/OpenVoiceOS/ovos-workshop/pull/342) ([JarbasAl](https://github.com/JarbasAl))



\* *This Changelog was automatically generated by [github_changelog_generator](https://github.com/github-changelog-generator/github-changelog-generator)*
